@@ -38,7 +38,7 @@ public:
     explicit inline KDbEscapedString(char ch)
         : QByteArray(1, ch), m_valid(true) {}
 
-    explicit inline KDbEscapedString(const QLatin1Char &ch)
+    explicit inline KDbEscapedString(QChar ch)
         : QByteArray(1, ch.toLatin1()), m_valid(true) {}
 
     explicit inline KDbEscapedString(const char* string)
@@ -58,8 +58,9 @@ public:
     //! @return invalid escaped string.
     static inline KDbEscapedString invalid() { return KDbEscapedString(false); }
 
-    //! @return true is the string valid. Valid string means that the escaping process has finished
-    //! successfully; it does not mean that the statement itself parses or executed without errors.
+    //! @return true if the string is valid. Valid string means that the escaping process
+    //! has finished successfully. It does not mean that the statement itself parses
+    //! or can be executed without errors.
     inline bool isValid() const { return m_valid; }
 
     inline QByteArray toByteArray() const { return static_cast<const QByteArray&>(*this); }
@@ -332,16 +333,16 @@ public:
     inline KDbEscapedString repeated(int times) const {
         return m_valid ? KDbEscapedString(QByteArray::repeated(times)) : KDbEscapedString::invalid();
     }
-    short toShort(bool *ok = 0, int base = 10) const;
-    ushort toUShort(bool *ok = 0, int base = 10) const;
-    int toInt(bool *ok = 0, int base = 10) const;
-    uint toUInt(bool *ok = 0, int base = 10) const;
-    long toLong(bool *ok = 0, int base = 10) const;
-    ulong toULong(bool *ok = 0, int base = 10) const;
-    qlonglong toLongLong(bool *ok = 0, int base = 10) const;
-    qulonglong toULongLong(bool *ok = 0, int base = 10) const;
-    float toFloat(bool *ok = 0) const;
-    double toDouble(bool *ok = 0) const;
+    short toShort(bool *ok = nullptr, int base = 10) const;
+    ushort toUShort(bool *ok = nullptr, int base = 10) const;
+    int toInt(bool *ok = nullptr, int base = 10) const;
+    uint toUInt(bool *ok = nullptr, int base = 10) const;
+    long toLong(bool *ok = nullptr, int base = 10) const;
+    ulong toULong(bool *ok = nullptr, int base = 10) const;
+    qlonglong toLongLong(bool *ok = nullptr, int base = 10) const;
+    qulonglong toULongLong(bool *ok = nullptr, int base = 10) const;
+    float toFloat(bool *ok = nullptr) const;
+    double toDouble(bool *ok = nullptr) const;
     inline KDbEscapedString toBase64() const {
         return m_valid ? KDbEscapedString(QByteArray::toBase64()) : KDbEscapedString::invalid();
     }
@@ -522,7 +523,7 @@ inline KDbEscapedString operator+(const KDbEscapedString &a1, const char* a2)
         return KDbEscapedString::invalid();
     return a1 + KDbEscapedString(a2);
 }
-inline KDbEscapedString operator+(const KDbEscapedString &a1, const QLatin1Char &a2)
+inline KDbEscapedString operator+(const KDbEscapedString &a1, QChar a2)
 {
     if (!a1.isValid())
         return KDbEscapedString::invalid();
@@ -552,7 +553,7 @@ inline KDbEscapedString operator+(const char* a1, const KDbEscapedString &a2)
         return KDbEscapedString::invalid();
     return KDbEscapedString(a1) + a2;
 }
-inline KDbEscapedString operator+(const QLatin1Char &a1, const KDbEscapedString &a2)
+inline KDbEscapedString operator+(QChar a1, const KDbEscapedString &a2)
 {
     if (!a2.isValid())
         return KDbEscapedString::invalid();
